// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('starter', ['ionic', 'ngAnimate', 'ngCordova'])
    .controller('cardController', ['$scope', '$timeout', '$window', '$cordovaGoogleAds', cardController])
    .run(startup)
    .config(config)
.directive('animateOnChange', function ($animate, $timeout) {
    return function (scope, elem, attr) {
        scope.$watch(attr.animateOnChange, function (nv, ov) {
            if (nv != ov) {
                var c = nv > ov ? 'change-up' : 'change';
                $animate.addClass(elem, c).then(function () {
                    $timeout(function () { $animate.removeClass(elem, c); });
                });
            }
        });
    };
});


function startup($ionicPlatform) {
    $ionicPlatform.ready(function () {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        }
        if (window.StatusBar) {
            StatusBar.styleDefault();
        }
    });
}
function config($stateProvider, $urlRouterProvider) {
    $stateProvider.state('index', {
        url: '',
        templateUrl: 'templates/home.html'
    }).state('encore', {
        url: 'encore',
        templateUrl: 'templates/encore.html',
        controller: 'cardController as vm'
    });
}

function cardController($scope, $timeout, $window, $cordovaGoogleAds) {
    var vm = this;
    vm.card = {};
    vm.score = [0, 0, 0, 0];
    var admobid = {
        banner: 'ca-app-pub-5422413832537104/9848340883',
        interstitial: 'ca-app-pub-5422413832537104/2325074085'
    };

    vm.addScore = function (team) { vm.score[team]++; };

    activate();

    function activate() {
        document.addEventListener('deviceready', onDeviceReady);
    }

    function onDeviceReady() {
        if ($cordovaGoogleAds) {
            setupAds();
        }
    }



    function setupAds() {
        vm.adSupport = 'Ads are supported';

        $cordovaGoogleAds.prepareInterstitial({
            adId: admobid.interstitial,
            isTesting: false,
            autoShow: false
        });

        $cordovaGoogleAds.showInterstitial()
            .then(function () {
                $cordovaGoogleAds.createBanner({
                    adId: admobid.banner,
                    adSize: $window.AdMob.AD_SIZE.BANNER,
                    position: $window.AdMob.AD_POSITION.BOTTOM_CENTER,
                    isTesting: false,
                    autoShow: true
                });
            });
    }


    var cards = [
        { text: '1', desc: 'Move forward one space, or remove one pawn from Start.', qty: 5, img: 'img/1.png' },
        { text: '2', desc: 'Move forward two spaces, or remove one pawn from Start and draw a card.', qty: 4, img: 'img/2.png' },
        { text: '3', desc: 'Move forward three spaces.', qty: 4, img: 'img/3.png' },
        { text: '4', desc: 'Move backward four spaces.', qty: 4, img: 'img/4.png' },
        { text: '5', desc: 'Move forward five spaces.', qty: 4, img: 'img/5.png' },
        { text: '7', desc: 'Move one pawn forward seven spaces, or split between two pawns.', qty: 4, img: 'img/7.png' },
        { text: '8', desc: 'Move forward eight spaces.', qty: 4, img: 'img/8.png' },
        { text: '10', desc: 'Move forward ten spaces, or backwards one.', qty: 4, img: 'img/10.png' },
        { text: '11', desc: 'Move forward eleven spaces, or switch places with an opponent.', qty: 4, img: 'img/11.png' },
        { text: '12', desc: 'Move forward twelve spaces.', qty: 4, img: 'img/12.png' },
        { text: 'SORRY!', desc: 'Take a pawn from Start and switch places with an opponent, then bump the opponent back to start.', qty: 4, img: 'img/sorry.png' }
    ];

    var deck = [];

    var allCards = {};

    function resetCards() {
        for (var i = 0; i < cards.length; i++) {
            var card = cards[i];
            for (var j = 0; j < card.qty; j++) {
                deck.push(card);
            }
        }
        allCards = deck.sort(shuffle);
    }

    resetCards();

    vm.nextCard = getNextCard;
    $timeout(function () {
        vm.card = allCards.shift();
        vm.showCard = true;
    }, 500);

    function getNextCard() {
        if (allCards.length) {
            vm.showCard = false;
            $timeout(function () {
                vm.card = allCards.shift();
                $timeout(function () { vm.showCard = true; }, 250);
            }, 250);
        } else {
            resetCards();
            getNextCard();
        }
    };
}


function randomList(obj) {
    var keys = Object.keys(obj)
    return obj[keys[keys.length * Math.random() << 0]];
}

function shuffle() {
    return 0.5 - Math.random();
}




